Module http

Module http 

HTTP server layer for RUEST (Axum + Tower, features complètes).

Axum est compilé avec HTTP/1, HTTP/2, WebSocket, multipart, form, query, etc. Voir axum_features pour le détail.

Re-exports

pub use axum;

Modules

axum_features
Documentation des capacités Axum activées par RUEST.
connect_info
Extractor for getting connection information from a client.
header
HTTP header types
ws
Handle WebSocket connections.

Structs

ApiResponse
Standard API response wrapper.
Body
The body type used in axum requests and responses.
Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
ConnectInfo
Extractor for getting connection information produced by a Connected.
DefaultBodyLimit
Layer for configuring the default request body limit.
Extension
Extractor and response for extensions.
Form
URL encoded extractor and response.
Json
JSON Extractor / Response.
MatchedPath
Access the path in the router that matches the request.
Multipart
Extractor that parses multipart/form-data requests (commonly used with file uploads).
Next
Next handler in the middleware pipeline.
OriginalUri
Extractor that gets the original request URI regardless of nesting.
Path
Extractor that will get captures from the URL and parse them using serde.
Query
Extractor that deserializes query strings into some type.
Request
Requête HTTP (http::Request<Body>). Represents an HTTP request.
State
Extractor for state.
WebSocket
A stream of WebSocket messages.
WebSocketUpgrade
Extractor for establishing WebSocket connections.

Enums

AppError
Erreurs métier avec messages humains (évite les messages Rust cryptiques côté API).
HttpError
Message
A WebSocket message.

Traits

Middleware
Middleware trait (NestJS / Axum style).
RequestExt
Extension trait that adds additional methods to Request.

Functions

serve
Build and serve a pre-assembled Axum router (routes monomorphisées au compile-time).

Type Aliases

AppResult
Résultat standard d’un handler ou service HTTP.