Module validation

Module validation 

Request validation for RUEST.

Structs

ValidatedJson
JSON extractor that runs validator automatically.

Enums

ValidationError

Traits

Validate
This is the original trait that was implemented by deriving Validate. It will still be implemented for struct validations that don’t take custom arguments. The call is being forwarded to the ValidateArgs<'v_a> trait.

Derive Macros

Validate