pub struct ToStrError { /* private fields */ }Expand description
A possible error when converting a HeaderValue to a string representation.
Header field values may contain opaque bytes, in which case it is not possible to represent the value as a string.